pub struct CharacterList {
pub characters: Vec<CharacterItem>,
pub loading: bool,
}Expand description
Holds data related to the current players characters, as well as some additional state to handle UI.
Fields
characters: Vec<CharacterItem>loading: boolTrait Implementations
Sourceimpl Debug for CharacterList
impl Debug for CharacterList
Sourceimpl Default for CharacterList
impl Default for CharacterList
Sourcefn default() -> CharacterList
fn default() -> CharacterList
Returns the “default value” for a type. Read more